# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,qshap_result)
S3method(gazer,catboost.Model)
S3method(gazer,default)
S3method(gazer,lgb.Booster)
S3method(gazer,xgb.Booster)
S3method(plot,qshap_rsq)
S3method(print,qshap_result)
S3method(print,qshap_rsq)
S3method(print,qshap_tree_explainer)
S3method(print,simple_tree)
S3method(print,tree_summary)
S3method(qshap_loss,qshap_tree_explainer)
S3method(summary,qshap_result)
S3method(summary,qshap_rsq)
S3method(summary,qshap_tree_explainer)
export(gazer)
export(loss)
export(qshap)
export(qshap_result)
export(rsq)
import(Rcpp)
import(ggplot2)
import(lightgbm)
importFrom(methods,new)
importFrom(parallel,clusterEvalQ)
importFrom(parallel,clusterExport)
importFrom(parallel,detectCores)
importFrom(parallel,makeCluster)
importFrom(parallel,parLapply)
importFrom(parallel,stopCluster)
importFrom(stats,predict)
importFrom(xgboost,xgb.model.dt.tree)
useDynLib(qshap, .registration = TRUE)
