# Generated by using Rcpp::compileAttributes() -> do not edit by hand
# Generator token: 10BE3573-1514-4C36-9D1C-5A225CD40393

compute_treeshap <- function(x, children_left, children_right, feature, threshold, value, n_node_samples) {
    .Call(`_qshap_compute_treeshap`, x, children_left, children_right, feature, threshold, value, n_node_samples)
}

T2 <- function(x, tree_summary, store_v_invc, store_z, parallel = TRUE) {
    .Call(`_qshap_T2`, x, tree_summary, store_v_invc, store_z, parallel)
}

loss_treeshap <- function(x, y, tree_summary, store_v_invc, store_z, T0_x, learning_rate = 1.0) {
    .Call(`_qshap_loss_treeshap`, x, y, tree_summary, store_v_invc, store_z, T0_x, learning_rate)
}

store_complex_v_invc <- function(d) {
    .Call(`_qshap_store_complex_v_invc`, d)
}

store_complex_root <- function(d) {
    .Call(`_qshap_store_complex_root`, d)
}

