% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/vis_module.R
\name{summary.qshap_rsq}
\alias{summary.qshap_rsq}
\title{Summary method for qshap_rsq objects}
\usage{
\method{summary}{qshap_rsq}(object, n = 10, ...)
}
\arguments{
\item{object}{A \code{qshap_rsq} object}

\item{n}{Integer number of top features to display (default: 10)}

\item{...}{Additional arguments (currently unused)}
}
\value{
The input \code{object} is returned invisibly. Called primarily for
  its side effect of printing a summary of the \code{qshap_rsq} object to
  the console.
}
\description{
Provides a summary of the qshap_rsq object, showing the top features by R-squared contribution
}
