% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/classes.R
\name{tree_summary}
\alias{tree_summary}
\title{User-friendly constructor for tree_summary}
\usage{
tree_summary(
  children_left,
  children_right,
  feature,
  feature_uniq,
  threshold,
  max_depth,
  sample_weight,
  init_prediction,
  node_count
)
}
\arguments{
\item{children_left}{Integer vector of left child indices}

\item{children_right}{Integer vector of right child indices}

\item{feature}{Integer vector of feature indices}

\item{feature_uniq}{Integer vector of unique feature indices used in tree}

\item{threshold}{Numeric vector of threshold values}

\item{max_depth}{Integer maximum depth}

\item{sample_weight}{Numeric vector of sample weights per node}

\item{init_prediction}{Numeric vector of initial predictions per node}

\item{node_count}{Integer total number of nodes}
}
\value{
A validated tree_summary object
}
\description{
User-friendly constructor for tree_summary
}
\keyword{internal}
